.. Copyright (C) 2018 Norbert Summer <git@o-g.at>
.. Copyright (C) 2018 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

``debops.prosody`` configures and manages the XMPP server prosody.
